#include "settings.h"
#include "settings.moc"

#include <qlabel.h>
#include <qhbox.h>
#include <qlayout.h>
#include <qcheckbox.h>
#include <qtabwidget.h>
#include <qhgroupbox.h>

#include <klocale.h>
#include <knuminput.h>
#include <kcolorbutton.h>

#include "piece.h"


BaseAppearanceConfig::BaseAppearanceConfig()
    : KConfigWidget(i18n("Appearance"), "colorize")
{
    QVBoxLayout *top = new QVBoxLayout(this);
    QTabWidget *tab = new QTabWidget(this);
    top->addWidget(tab, 1);

// main tab
    QWidget *page = new QWidget(tab);
    tab->addTab(page, i18n("Main"));
    top = new QVBoxLayout(page, KDialog::marginHint(), KDialog::spacingHint());

    // upper part
    _main = new QWidget(page);
    top->addWidget(_main);
    _grid = new QGridLayout(_main, 3, 2, 0, KDialog::spacingHint());

    QLabel *label = new QLabel(_main);
    _grid->addWidget(label, 0, 0);
    KIntNumInput *in = new KIntNumInput(_main);
    in->setRange(0, 100); // #### just to add a slider !
    KConfigItem *set = configCollection()->plug("block size", in);
    set->setProxyLabel(label);
    _grid->addWidget(in, 0, 1);

    _grid->addRowSpacing(1, KDialog::spacingHint());

    QCheckBox *chb = new QCheckBox(_main);
    configCollection()->plug("enable animations", chb);
    _grid->addMultiCellWidget(chb, 2, 2, 0, 1);

    top->addSpacing(KDialog::spacingHint());

    // lower part
    QHGroupBox *gbox = new QHGroupBox(i18n("Background"), page);
    top->addWidget(gbox);
    QWidget *widget = new QWidget(gbox);
    QGridLayout *grid =
        new QGridLayout(widget, 2, 3, 0, KDialog::spacingHint());
    label = new QLabel(widget);
    grid->addWidget(label, 0, 0);
    KDoubleNumInput *dn = new KDoubleNumInput(widget);
    dn->setRange(0, 100, 0.01); // #### to add a slider and set the step !
    set = configCollection()->plug("fade intensity", dn);
    set->setProxyLabel(label);
    grid->addMultiCellWidget(dn, 0, 0, 1, 2);
    label = new QLabel(widget);
    grid->addWidget(label, 1, 0);
    KColorButton *cob = new KColorButton(widget);
    set = configCollection()->plug("fade color", cob);
    set->setProxyLabel(label);
    grid->addWidget(cob, 1, 1);

    top->addStretch(1);

// colors tab
    page = new QWidget(tab);
    tab->addTab(page, i18n("Colors"));
    uint nb = Piece::info()->nbColors();
    grid = new QGridLayout(page, nb+1, 3, KDialog::marginHint(),
                           KDialog::spacingHint());
    grid->setColStretch(2, 1);

    for (uint i=0; i<nb; i++) {
        label = new QLabel(page);
        grid->addWidget(label, i, 0);
        cob = new KColorButton(page);
        cob->setFixedWidth(100);
        grid->addWidget(cob, i, 1);
        KConfigItem *set =
            configCollection()->plug(Piece::info()->colorKey(i).utf8(), cob);
        set->setProxyLabel(label);
    }

    grid->setRowStretch(nb, 1);
}
